@@ -87,8 +87,8 @@ class Dagobah(object):
         rec = self.backend.decode_import_json(job_json)
         if destructive:
             try:
-                dagobah.delete_job(rec['name'])
-            except:
+                self.delete_job(rec['name'])
+            except DagobahError:  # expected if no job with this name
                 pass
         self._add_job_from_spec(rec, use_job_id=False)
 
@@ -576,13 +576,15 @@ class Job(DAG):
                                  strict_json=strict_json)
                  for task in self.tasks.itervalues()]
 
+        dependencies = {}
+        for k, v in self.graph.iteritems():
+            dependencies[k] = list(v)
+
         result = {'job_id': self.job_id,
                   'name': self.name,
                   'parent_id': self.parent.dagobah_id,
                   'tasks': t,
-                  'dependencies': {k: list(v)
-                                   for k, v
-                                   in self.graph.iteritems()},
+                  'dependencies': dependencies,
                   'status': self.state.status,
                   'cron_schedule': self.cron_schedule,
                   'next_run': self.next_run}
